@@ -1,4 +1,4 @@
 from .psi.rsa_intersecter import *  # noqa
 from .hetero_nn import *  # noqa
-from .hetero_nn_client import HeteroNNCollaboraterScheduler  # noqa
+from .hetero_nn_client import HeteroNNCollaboratorScheduler  # noqa
 from ..scheduler import register_metrics  # noqa
