@@ -18,7 +18,7 @@ import torch.optim as optim
 from .. import logger
 from ..data_channel import GRPCDataChannel
 from ..scheduler import ConfigError, Scheduler, TaskFailed
-from .contractor import (CheckinEvent, CollaboraterCompleteEvent,
+from .contractor import (CheckinEvent, CollaboratorCompleteEvent,
                          HeteroNNContractor, SendFeatureEvent,
                          SendTestFeatureEvent, SyncStateResponseEvent)
 from .psi import RSAPSIInitiatorScheduler
@@ -77,20 +77,27 @@ class HeteroNNScheduler(Scheduler, metaclass=ABCMeta):
         self.contractor = HeteroNNContractor(task_id=task_id)
         self.data_channel = GRPCDataChannel(self.contractor)
 
-    @abstractmethod
-    def _launch_process(self):
-        ...
-
     @abstractmethod
     def load_local_ids(self) -> List[str]:
         """Load all local data IDs for PSI."""
 
+    @abstractmethod
+    def split_dataset(self, id_intersection: Set[str]) -> Tuple[Set[str], Set[str]]:
+        """Split dataset into train set and test set.
+
+        NOTE: Must make sure each node gets the same split results.
+
+        :return
+            A tuple of ID set of training dataset and of testing dataset:
+            (Set[train_ids], Set[test_ids]).
+        """
+
     @abstractmethod
     def make_feature_model(self) -> nn.Module:
         """Return a model object to project input to features.
 
         The output of feature model MUST be a (str_keyword, torch.Tensor) tuple, where
-        str_keyword is used by the host to distinguish features from collaboraters
+        str_keyword is used by the host to distinguish features from collaborators
         and Tensor is a two dimension (batch, feature_vector) tensor as the input
         of projection layer.
         """
@@ -129,23 +136,12 @@ class HeteroNNScheduler(Scheduler, metaclass=ABCMeta):
         assert self._id_intersection is not None, 'Have not run ID intersection process.'
         return self._id_intersection
 
-    @abstractmethod
-    def split_data_set(self, id_intersection: Set[str]) -> Tuple[Set[str], Set[str]]:
-        """Split dataset into train set and test set.
-
-        NOTE: Must make sure each node gets the same split results.
-
-        :return
-            A tuple of ID set of training dataset and of testing dataset:
-            (Set[train_ids], Set[test_ids]).
-        """
-
     @property
     def train_ids(self) -> Set[str]:
         """Return the ID set of training dataset intersection."""
         if not hasattr(self, '_train_ids'):
             assert self.id_intersection, 'Must get the whole ID intersection at first.'
-            self._train_ids, self._test_ids = self.split_data_set(self.id_intersection.copy())
+            self._train_ids, self._test_ids = self.split_dataset(self.id_intersection.copy())
         return self._train_ids
 
     @property
@@ -153,9 +149,13 @@ class HeteroNNScheduler(Scheduler, metaclass=ABCMeta):
         """Return the ID set of testing dataset intersection."""
         if not hasattr(self, '_test_ids'):
             assert self.id_intersection, 'Must get the whole ID intersection at first.'
-            self._train_ids, self._test_ids = self.split_data_set(self.id_intersection.copy())
+            self._train_ids, self._test_ids = self.split_dataset(self.id_intersection.copy())
         return self._test_ids
 
+    @abstractmethod
+    def _launch_process(self):
+        """Run the main process of the task."""
+
     def _run(self, id: str, task_id: str, is_initiator: bool = False):
         self._setup_context(id=id, task_id=task_id, is_initiator=is_initiator)
         self.push_log(message='Local context is ready.')
@@ -176,8 +176,6 @@ class HeteroNNHostScheduler(HeteroNNScheduler):
 
     def __init__(self,
                  feature_key: str,
-                 project_layer_config: List[Tuple[str, int, int]],
-                 project_layer_lr: float,
                  name: str = None,
                  max_rounds: int = 0,
                  calculation_timeout: int = 300,
@@ -190,16 +188,7 @@ class HeteroNNHostScheduler(HeteroNNScheduler):
         :args
             :feature_key
                 A unique key of feature used by the host to distinguish features
-                from collaboraters.
-            :project_layer_config
-                The input => output rule to define projection matrics which are used
-                to project each node's feature tensor to fuse into the input of infer model.
-                Each record contains three element: keyword, input_dimension, output_dimension.
-                The keyword is used to distinguish features' owner, the input_dimension
-                gives the dimension of the feature, the output_dimension defines the
-                dimension of the projection result.
-            :project_layer_lr
-                The learning rate of project layer.
+                from collaborators.
             :name
                 Default to the task ID.
             :max_rounds
@@ -226,8 +215,6 @@ class HeteroNNHostScheduler(HeteroNNScheduler):
         self._switch_status(self._INIT)
 
         self.feature_key = feature_key
-        self.project_layer_config = project_layer_config
-        self.project_layer_lr = project_layer_lr
         self.name = name
         self.max_rounds = max_rounds
         self.calculation_timeout = calculation_timeout
@@ -254,24 +241,6 @@ class HeteroNNHostScheduler(HeteroNNScheduler):
     def _validate_config(self):
         if not self.feature_key or not isinstance(self.feature_key, str):
             raise ConfigError('Must specify a feature_key of type string.')
-        if not self.project_layer_config or not isinstance(self.project_layer_config, list):
-            raise ConfigError(f'Invalid project layer config: {self.project_layer_config}.')
-        for _config in self.project_layer_config:
-            if not _config or not isinstance(_config, tuple) or len(_config) != 3:
-                raise ConfigError(f'Invalid project layer config items: {_config}.')
-            _key, _in_dim, _out_dim = _config
-            if (
-                not _key or not isinstance(_key, str)
-                or not _in_dim or not isinstance(_in_dim, int) or _in_dim < 1
-                or not _out_dim or not isinstance(_out_dim, int) or _out_dim < 1
-            ):
-                raise ConfigError(f'Invalid project layer config items: {_config}.')
-        if (
-            not self.project_layer_lr
-            or not isinstance(self.project_layer_lr, float)
-            or self.project_layer_lr <= 0
-        ):
-            raise ConfigError(f'Invalid project layer learning rate: {self.project_layer_lr}.')
 
     @abstractmethod
     def make_infer_model(self) -> nn.Module:
@@ -601,7 +570,7 @@ class HeteroNNHostScheduler(HeteroNNScheduler):
         raise TaskFailed('Failed to collect all features.')
 
     def _distribute_feature_grad(self):
-        """Distribute feature grad tensors to collaboraters."""
+        """Distribute feature grad tensors to collaborators."""
         self.push_log('Distributing features grad tensors ...')
         for _partner, _feature_dict in self._alpha_map.items():
             if _partner == self.id:
@@ -615,7 +584,7 @@ class HeteroNNHostScheduler(HeteroNNScheduler):
                                               data_stream=tf.read(),
                                               connection_timeout=self.dc_conn_timeout,
                                               timeout=self.dc_timeout)
-        self.push_log('Distributed all features grad tensors to collaboraters.')
+        self.push_log('Distributed all features grad tensors to collaborators.')
 
     def _save_model(self):
         """Save latest model state."""
@@ -742,12 +711,12 @@ class HeteroNNHostScheduler(HeteroNNScheduler):
         return report_file_path, model_file_path
 
     def _wait_for_all_complete(self):
-        """Wait for all collaboraters complete their tasks."""
-        self.push_log('Waiting for all collaboraters complete their tasks ...')
+        """Wait for all collaborators complete their tasks."""
+        self.push_log('Waiting for all collaborators complete their tasks ...')
         results = {_peer_id: False for _peer_id in self._partners}
         for _event in self.contractor.contract_events():
-            if isinstance(_event, CollaboraterCompleteEvent):
+            if isinstance(_event, CollaboratorCompleteEvent):
                 results[_event.peer_id] = True
                 if all(results.values()):
                     break
-        self.push_log('All collaboraters have completed their tasks.')
+        self.push_log('All collaborators have completed their tasks.')
