@@ -23,7 +23,7 @@ from ..data_channel import GRPCDataChannel
 from ..scheduler import ConfigError, Scheduler, TaskFailed
 from .hetero_nn import _SimplifiedOptimizer
 from .psi import RSAPSIInitiatorScheduler
-from .secure_contractor import (CheckinEvent, CollaboraterCompleteEvent,
+from .secure_contractor import (CheckinEvent, CollaboratorCompleteEvent,
                                 HeteroNNContractor, SendFeatureEvent,
                                 SendNoisedPorjectionEvent,
                                 SendNoisedWGradEvent, SyncStateResponseEvent)
@@ -231,7 +231,7 @@ class SecureHeteroNNScheduler(Scheduler, metaclass=ABCMeta):
         """Return a model object to project input to features.
 
         The output of feature model MUST be a (str_keyword, torch.Tensor) tuple, where
-        str_keyword is used by the host to distinguish features from collaboraters
+        str_keyword is used by the host to distinguish features from collaborators
         and Tensor is a two dimension (batch, feature_vector) tensor as the input
         of projection layer.
         """
@@ -271,7 +271,7 @@ class SecureHeteroNNScheduler(Scheduler, metaclass=ABCMeta):
         return self._id_intersection
 
     @abstractmethod
-    def split_data_set(self, id_intersection: Set[str]) -> Tuple[Set[str], Set[str]]:
+    def split_dataset(self, id_intersection: Set[str]) -> Tuple[Set[str], Set[str]]:
         """Split dataset into train set and test set.
 
         NOTE: Must make sure each node gets the same split results.
@@ -286,7 +286,7 @@ class SecureHeteroNNScheduler(Scheduler, metaclass=ABCMeta):
         """Return the ID set of training dataset intersection."""
         if not hasattr(self, '_train_ids'):
             assert self.id_intersection, 'Must get the whole ID intersection at first.'
-            self._train_ids, self._test_ids = self.split_data_set(self.id_intersection.copy())
+            self._train_ids, self._test_ids = self.split_dataset(self.id_intersection.copy())
         return self._train_ids
 
     @property
@@ -294,7 +294,7 @@ class SecureHeteroNNScheduler(Scheduler, metaclass=ABCMeta):
         """Return the ID set of testing dataset intersection."""
         if not hasattr(self, '_test_ids'):
             assert self.id_intersection, 'Must get the whole ID intersection at first.'
-            self._train_ids, self._test_ids = self.split_data_set(self.id_intersection.copy())
+            self._train_ids, self._test_ids = self.split_dataset(self.id_intersection.copy())
         return self._test_ids
 
     def _run(self, id: str, task_id: str, is_initiator: bool = False):
@@ -335,7 +335,7 @@ class SecureHeteroNNHostScheduler(SecureHeteroNNScheduler):
         :args
             :feature_key
                 A unique key of feature used by the host to distinguish features
-                from collaboraters.
+                from collaborators.
             :project_layer_config
                 The input => output rule to define projection matrics which are used
                 to project each node's feature tensor to fuse into the input of infer model.
@@ -814,8 +814,8 @@ class SecureHeteroNNHostScheduler(SecureHeteroNNScheduler):
         self._feature_projection_map = self.project_layer(features)
 
     def _distribute_cipher_projection(self):
-        """Distribute cipher feature projection to collaboraters."""
-        self.push_log('Distributing cipher projection to collaboraters ...')
+        """Distribute cipher feature projection to collaborators."""
+        self.push_log('Distributing cipher projection to collaborators ...')
         self._epsilon_host = random.randint(1, 2**10)
         for _partner, _cipher_feature in self._alpha_map.items():
             if _partner == self.id:
@@ -830,12 +830,12 @@ class SecureHeteroNNHostScheduler(SecureHeteroNNScheduler):
                                           data_stream=cipher_projection.to_bytes(),
                                           connection_timeout=self.dc_conn_timeout,
                                           timeout=self.dc_timeout)
-            self.push_log(f'Distributed cipher projection to collaborater ID: {_partner}')
+            self.push_log(f'Distributed cipher projection to collaborator ID: {_partner}')
 
     @torch.no_grad()
     def _collect_noised_projection(self):
-        """Collect noised but plain projection from collaboraters."""
-        self.push_log('Collecting noised but plain projection from collaboraters ...')
+        """Collect noised but plain projection from collaborators."""
+        self.push_log('Collecting noised but plain projection from collaborators ...')
         self.contractor.notify_ready_for_noised_projection(round=self._round)
         self._feature_fusion_map = {
             self.feature_key: self._feature_projection_map[self.feature_key]
@@ -858,7 +858,7 @@ class SecureHeteroNNHostScheduler(SecureHeteroNNScheduler):
 
     def _distribute_cipher_w_grad(self):
         self._epsilon_host = random.randint(1, 2**10)
-        self.push_log('Distributing cipher W grad to collaboraters ...')
+        self.push_log('Distributing cipher W grad to collaborators ...')
         for _partner, feature_dict in self._alpha_map.items():
             if _partner == self.id:
                 continue
@@ -873,12 +873,12 @@ class SecureHeteroNNHostScheduler(SecureHeteroNNScheduler):
                                           connection_timeout=self.dc_conn_timeout,
                                           timeout=self.dc_timeout)
             self.push_log(f'Sent cipher W grad to ID: {_partner}.')
-        self.push_log('Distributed all cipher W grad to collaboraters.')
+        self.push_log('Distributed all cipher W grad to collaborators.')
 
     def _collect_noised_w_grad(self):
-        """Collect decrypted but noised W grad of project layer from collaboraters."""
+        """Collect decrypted but noised W grad of project layer from collaborators."""
         self.contractor.notify_ready_for_noised_w_grad(round=self._round)
-        self.push_log('Collecting noised W grad from collaboraters ...')
+        self.push_log('Collecting noised W grad from collaborators ...')
         self._noised_w_grad_map.clear()
         for _event in self.contractor.contract_events(timeout=self.schedule_timeout):
             if isinstance(_event, SendNoisedWGradEvent):
@@ -891,8 +891,8 @@ class SecureHeteroNNHostScheduler(SecureHeteroNNScheduler):
         self.push_log('Received all copies of noised W grad.')
 
     def _distribute_cipher_feature_grad(self):
-        """Send cipher feature grad to collaboraters."""
-        self.push_log('Distributing cipher feature grad to collaboraters ...')
+        """Send cipher feature grad to collaborators."""
+        self.push_log('Distributing cipher feature grad to collaborators ...')
         for _partner, feature_dict in self._alpha_map.items():
             if _partner == self.id:
                 continue
@@ -911,7 +911,7 @@ class SecureHeteroNNHostScheduler(SecureHeteroNNScheduler):
                                           connection_timeout=self.dc_conn_timeout,
                                           timeout=self.dc_timeout)
             self.push_log(f'Sent cipher feature grad to ID {_partner}.')
-        self.push_log('Distributed all cipher feature grad to collaboraters.')
+        self.push_log('Distributed all cipher feature grad to collaborators.')
 
     @torch.no_grad()
     def _update_project_layer_weight(self):
@@ -1049,12 +1049,12 @@ class SecureHeteroNNHostScheduler(SecureHeteroNNScheduler):
         return report_file_path, model_file_path
 
     def _wait_for_all_complete(self):
-        """Wait for all collaboraters complete their tasks."""
-        self.push_log('Waiting for all collaboraters complete their tasks ...')
+        """Wait for all collaborators complete their tasks."""
+        self.push_log('Waiting for all collaborators complete their tasks ...')
         results = {_peer_id: False for _peer_id in self._partners}
         for _event in self.contractor.contract_events():
-            if isinstance(_event, CollaboraterCompleteEvent):
+            if isinstance(_event, CollaboratorCompleteEvent):
                 results[_event.peer_id] = True
                 if all(results.values()):
                     break
-        self.push_log('All collaboraters have completed their tasks.')
+        self.push_log('All collaborators have completed their tasks.')
